@@ -4,7 +4,7 @@
 #' @author Jun Park, \email{jp84 at iu dot edu}
 #' @param formula a formula object relating survival object \code{Surv2(v, u, event)} to a set of covariates
 #' @param data a data frame that includes the variables named in the formula argument
-#' @param alpha \eqn{\alpha = (\alpha1, \alpha2)} contains parameters that define the link functions from class of generalized odds-rate transformation models. The components \eqn{\alpha1} and \eqn{\alpha2} should both be \eqn{\ge 0}. If \eqn{\alpha1 = 0}, the user assumes a proportional subdistribution hazards model or Fine-Gray model for the cause of failure 1. If \eqn{\alpha2 = 1}, the user assumes a proportional odds model for the cause of failure 2.
+#' @param alpha \eqn{\alpha = (\alpha1, \alpha2)} contains parameters that define the link functions from class of generalized odds-rate transformation models. The components \eqn{\alpha1} and \eqn{\alpha2} should both be \eqn{\ge 0}. If \eqn{\alpha1 = 0}, the user assumes the proportional subdistribution hazards model or the Fine-Gray model for the cause of failure 1. If \eqn{\alpha2 = 1}, the user assumes the proportional odds model for the cause of failure 2.
 #' @keywords bssmle
 #' @import stats
 #' @importFrom alabama constrOptim.nl
@@ -328,7 +328,7 @@ bssmle <- function(formula, data, alpha){
                 varnames = colnames(Z),
                 alpha = alpha,
                 loglikelihood = NA,
-                convergence = ifelse(est$convergence == 0, "Converged", "Did not converge"),
+                convergence = "Did not converge",
                 tms = c(min(t), max(t)))
     res
   }
